c ######################################################################
c #
c #                      MgB2 PROPERTIES PACKAGE
c #                  ------------------------------
c # Contains functions for the calculation of the thermo-physical
c # properties of MgB2
c #
c ######################################################################

c ######################################################################
      real function dMgB2(T)
c ######################################################################
c #
c # Density of MgB2
c #
c # Range: Tmin <= T <= Tmax K
c #
c #                        References
c #                        ----------
c # Reference
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   dMgB2             x    density                           kg/m**3
c #
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      dMgB2 = 0.0
c *

      return
      end
c ######################################################################
      real function cMgB2(T,B,Epslon)
c ######################################################################
c #
c # Specific heat of MgB2
c #
c # Range: Tmin <= T <= Tmax
c #
c #                        References
c #                        ----------
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   B               x      magnetic field                    T
c #   Epslon          x      strain                            -
c #   cMgB2             x    specific heat                     J/Kg K
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T,B,Epslon
c * fit variables

c * local variables

c *
      cMgB2 = 0.0
c *
      return
      end
c ######################################################################
      real function kMgB2(T)
c ######################################################################
c #
c # Thermal conductivity of MgB2
c #
c # Range: Tmin <= T <= Tmax K
c #
c #                        References
c #                        ----------
c # Reference
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   kMgB2             x    thermal conductivity              W/m K
c #
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      kMgB2 = 0.0
c *

      return
      end
c ######################################################################
      real function rMgB2(T)
c ######################################################################
c #
c # Electrical resistivity of MgB2
c #
c # Range: Tmin <= T <= Tmax K
c #
c #                        References
c #                        ----------
c # Reference
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   rMgB2             x    resistivity                       Ohm m
c #
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      rMgB2 = 0.0
c *

      return
      end
c ######################################################################
      real function TcMgB2(B,Epslon)
c ######################################################################
c #
c # Critical temperature, in K, for MgB2 as a function of applied field
c #
c #                        References
c #                        ----------
c #
c # variable    I/O               meaning                        units
c # --------------------------------------------------------------------
c #   B         x            magnetic field                        T
c #   Epslon    x            strain                                -
c #   TcMgB2       x         critical temperature                  K
c #
c # Other functions called: NONE
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c *
      real     B,Epslon
c * fit variables      

c * local variables

c *      
      TcMgB2 = 0.0

c *
      return
      end
c ######################################################################
      real function BcMgB2(T,Epslon)
c ######################################################################
c #
c # Upper critical field, in T, for MgB2 as a function of field
c #
c #                        References
c #                        ----------
c #
c # variable    I/O               meaning                        units
c # --------------------------------------------------------------------
c #   T         x            magnetic field                        K
c #   Epslon    x            strain                                -
c #   BcMgB2      x          critical field                        T
c #
c # Other functions called: NONE
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c *
      real     T,Epslon
c * fit variables      

c * local variables

c *      
      BcMgB2 = 0.0

c *
      return
      end
c ######################################################################
      real function JcMgB2(T,B,Epslon)
c ######################################################################
c #
c # Critical (non-copper) current density, in A/m**2, for MgB2 as a
c # function of temperature and field. 
c #
c #                        References
c #                        ----------
c #
c #
c # variable    I/O               meaning                        units
c # --------------------------------------------------------------------
c #   T         x            absolute temperature                  K
c #   B         x            magnetic field                        T
c #   Epslon    x            strain                                -
c #   JcMgB2      x          critical current density            A/m**2
c #
c # Other functions called: NONE
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c *
      real     T,B,Epslon
c * fit variables      

c * local variables

c *      
      JcMgB2 = 0.0

c *
      return
      end
c ######################################################################
      real function TcsMgB2(B,Epslon,Jop)
c ######################################################################
C #
C # Current sharing temperature, in K, for MgB2 as a function of field
C # and operating current density.
C #
C # variable    I/O               meaning                        units
C # --------------------------------------------------------------------
C #   B         x            magnetic field                        T
c #   Epslon    x            strain                                -
C #   Jop       x            operating current density           A/m**2  
c #   TcsMgB2     x          current sharing temperature           K
c #
c # Other functions called: 
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c *
      real     B,Epslon,Jop
c * fit variables      

c * local variables

c *      
      TcsMgB2 = 0.0

c *
      return
      end
